=============================
Adding a custom storage class
=============================
If a different database is to be used for persisting the telemetry
object then you can achieve this by creating a custom storage class.
